@@ -49,6 +49,7 @@ date         init     comment
 #include "agt_if.h"
 #include "agt_ncx.h"
 #include "agt_not.h"
+#include "agt_not_queue_notification_cb.h"
 #include "agt_plock.h"
 #include "agt_proc.h"
 #include "agt_rpc.h"
@@ -60,7 +61,8 @@ date         init     comment
 #include "agt_time_filter.h"
 #include "agt_timer.h"
 #include "agt_util.h"
-#include "agt_yuma_arp.h"
+#include "agt_yang_library.h"
+
 #include "log.h"
 #include "ncx.h"
 #include "ncx_str.h"
@@ -75,7 +77,7 @@ date         init     comment
 *                                                                   *
 *********************************************************************/
 
-#define TX_ID_MODULE    (const xmlChar *)"yuma-system"
+#define TX_ID_MODULE    (const xmlChar *)"yuma123-system"
 #define TX_ID_OBJECT    (const xmlChar *)"transaction-id"
 
 
@@ -127,8 +129,8 @@ static void
     agt_profile.agt_has_startup = FALSE;
     agt_profile.agt_usestartup = TRUE;
     agt_profile.agt_factorystartup = FALSE;
-    agt_profile.agt_startup_error = FALSE;
-    agt_profile.agt_running_error = FALSE;
+    agt_profile.agt_startup_error = TRUE;
+    agt_profile.agt_running_error = TRUE;
     agt_profile.agt_logappend = FALSE;
     agt_profile.agt_xmlorder = FALSE;
     agt_profile.agt_deleteall_ok = FALSE;
@@ -696,6 +698,12 @@ status_t
     /* initialize the session handler data structures */
     agt_ses_init();
 
+    /* load the yang library module */
+    res = agt_yang_library_init();
+    if (res != NO_ERR) {
+        return res;
+    }
+
     /* load the system module */
     res = agt_sys_init();
     if (res != NO_ERR) {
@@ -750,12 +758,6 @@ status_t
         return res;
     }
 
-    /* load the yuma-arp module */
-    res = y_yuma_arp_init(y_yuma_arp_M_yuma_arp, NULL);
-    if (res != NO_ERR) {
-        return res;
-    }
-
     /* check the module parameter set from CLI or conf file
      * for any modules to pre-load
      */
@@ -912,6 +914,12 @@ status_t
         return res;
     }
 
+    /* load any yang library module non-config data */
+    res = agt_yang_library_init2();
+    if (res != NO_ERR) {
+        return res;
+    }
+
     /* load any system module non-config data */
     res = agt_sys_init2();
     if (res != NO_ERR) {
@@ -956,12 +964,6 @@ status_t
         return res;
     }
 
-    /* load the yuma arp callbacks */
-    res = y_yuma_arp_init2();
-    if (res != NO_ERR) {
-        return res;
-    }
-
 #ifdef STATIC_SERVER
     /* init phase 2 for static modules should be 
      * initialized here
@@ -1159,6 +1161,7 @@ void
         agt_ncx_cleanup();
         agt_hello_cleanup();
         agt_cli_cleanup();
+        agt_yang_library_cleanup();
         agt_sys_cleanup();
         agt_state_cleanup();
         agt_not_cleanup();
@@ -1166,7 +1169,6 @@ void
         y_ietf_netconf_partial_lock_cleanup();
         agt_if_cleanup();
         y_yuma_time_filter_cleanup();
-        y_yuma_arp_cleanup();
         agt_ses_cleanup();
         agt_cap_cleanup();
         agt_rpc_cleanup();
@@ -1521,6 +1523,10 @@ boolean
         return FALSE;
     }
 
+    if (!xml_strcmp(modname, NCXMOD_NETCONFD_EX)) {
+        return FALSE;
+    }
+
     clivalset = agt_cli_get_valset();
     val = val_find_child(clivalset, NCXMOD_NETCONFD_EX, NCX_EL_NON_ADVERTISED_MODULE);
 
