@@ -1236,7 +1236,7 @@ static const char* get_rule_queue_access_str(unsigned int access_id)
     }
 }
 
-static unsigned int get_rule_queue_access_id(char* access_str)
+static unsigned int get_rule_queue_access_id(const char* access_str)
 {
     if(0==strcmp("read", access_str)) {
         return DATA_RULE_QUEUE_READ;
@@ -1541,6 +1541,12 @@ static boolean
         return TRUE;
     }
 
+    /* super user is allowed to access anything except user-write blocked */
+    if (is_superuser(user)) {
+        (*logfn)("\nagt_acm: PERMIT (superuser)");
+        return TRUE;
+    }
+
     /* ncx:user-write blocking has highest priority */
     if(iswrite) {
         switch (editop) {
@@ -1577,12 +1583,6 @@ static boolean
         access = "read";
     }
 
-    /* super user is allowed to access anything except user-write blocked */
-    if (is_superuser(user)) {
-        (*logfn)("\nagt_acm: PERMIT (superuser)");
-        return TRUE;
-    }
-
     if (cache->mode == AGT_ACMOD_DISABLED) {
         (*logfn)("\nagt_acm: PERMIT (NACM disabled)");
         return TRUE;
