@@ -1,5 +1,6 @@
 /*
  * Copyright (c) 2008 - 2012, Andy Bierman, All Rights Reserved.
+ * Copyright (c) 2013 - 2017, Vladimir Vassilev, All Rights Reserved.
  * 
  * Unless required by applicable law or agreed to in writing,
  * software distributed under the License is distributed on an
@@ -184,9 +185,12 @@ date         init     comment
 
 static boolean              agt_sys_init_done = FALSE;
 
-/* system.yang */
+/* ietf-system.yang */
 static ncx_module_t         *ietf_sysmod;
+/* system.yang */
 static ncx_module_t         *sysmod;
+/* ietf-netconf-notifications.yang */
+static ncx_module_t         *ietf_netconf_notifications_mod;
 
 /* cached pointer to the <system> element template */
 static obj_template_t *ietf_system_state_obj;
@@ -194,9 +198,7 @@ static obj_template_t *yuma_system_obj;
 
 /* cached pointers to the eventType nodes for this module */
 static obj_template_t *sysStartupobj;
-static obj_template_t *sysConfigChangeobj;
 static obj_template_t *sysCapabilityChangeobj;
-static obj_template_t *sysSessionStartobj;
 static obj_template_t *sysSessionEndobj;
 static obj_template_t *sysConfirmedCommitobj;
 
@@ -423,7 +425,7 @@ static void
 
 
 /********************************************************************
-* FUNCTION add_common_session_parms
+* FUNCTION netconf_notifications_add_common_session_parms
 *
 * Add the leafs from the SysCommonSessionParms grouping
 *
@@ -435,23 +437,36 @@ static void
 *   'not' payloadQ has malloced entries added to it
 *********************************************************************/
 static void
-    add_common_session_parms (const ses_cb_t *scb,
-                              agt_not_msg_t *not)
+    netconf_notifications_add_common_session_parms (const ses_cb_t *scb,
+                              agt_not_msg_t *not,
+                              val_value_t* parent_val)
 {
+    obj_template_t  *parent_obj;
     val_value_t     *leafval;
     status_t         res;
     ses_id_t         use_sid;
 
+    if(not!=NULL) {
+        assert(parent_val==NULL);
+        parent_obj = not->notobj;
+    } else if(parent_val!=NULL) {
+        assert(not==NULL);
+        parent_obj=parent_val->obj;
+    } else {
+        assert(0);
+    }
+
     /* add userName */
     if (scb->username) {
-        leafval = agt_make_leaf(not->notobj,
-                                system_N_userName,
+        leafval = agt_make_leaf(parent_obj,
+                                "username",
                                 scb->username,
                                 &res);
-        if (leafval) {
+        assert(leafval);
+        if(not) {
             agt_not_add_to_payload(not, leafval);
         } else {
-            payload_error(system_N_userName, res);
+            val_add_child(leafval, parent_val);
         }
     }
 
@@ -465,33 +480,34 @@ static void
         use_sid = 0;
     }
 
-    leafval = NULL;
     if (use_sid) {
-        leafval = agt_make_uint_leaf(not->notobj,
-                                     system_N_sessionId,
-                                     use_sid,
-                                     &res);
-    }
-    if (leafval) {
-        agt_not_add_to_payload(not, leafval);
-    } else {
-        payload_error(system_N_sessionId, res);
+        leafval = agt_make_uint_leaf(parent_obj,
+                                "session-id",
+                                use_sid,
+                                &res);
+        assert(leafval);
+        if(not) {
+            agt_not_add_to_payload(not, leafval);
+        } else {
+            val_add_child(leafval, parent_val);
+        }
     }
 
     /* add remoteHost */
     if (scb->peeraddr) {
-        leafval = agt_make_leaf(not->notobj,
-                                system_N_remoteHost,
+        leafval = agt_make_leaf(parent_obj,
+                                "source-host",
                                 scb->peeraddr,
                                 &res);
-        if (leafval) {
+        assert(leafval);
+        if(not) {
             agt_not_add_to_payload(not, leafval);
         } else {
-            payload_error(system_N_remoteHost, res);
+            val_add_child(leafval, parent_val);
         }
     }
 
-} /* add_common_session_parms */
+} /* netconf_notifications_add_common_session_parms */
 
 
 /********************************************************************
@@ -508,9 +524,7 @@ static void
     ietf_system_state_obj = NULL;
     yuma_system_obj = NULL;
     sysStartupobj = NULL;
-    sysConfigChangeobj = NULL;
     sysCapabilityChangeobj = NULL;
-    sysSessionStartobj = NULL;
     sysSessionEndobj = NULL;
     sysConfirmedCommitobj = NULL;
 
@@ -567,6 +581,15 @@ status_t
         return res;
     }
 
+    /* load the ietf-netconf-notifications module */
+    res = ncxmod_load_module("ietf-netconf-notifications",
+                             NULL,
+                             &agt_profile->agt_savedevQ,
+                             &ietf_netconf_notifications_mod);
+    if (res != NO_ERR) {
+        return res;
+    }
+
     /* find the object definition for the system element */
     ietf_system_state_obj = ncx_find_object(ietf_sysmod,
                                 ietf_system_N_system_state);
@@ -590,41 +613,6 @@ status_t
         return SET_ERROR(ERR_NCX_DEF_NOT_FOUND);
     }
 
-    sysConfigChangeobj = 
-        ncx_find_object(sysmod,
-                        system_N_sysConfigChange);
-    if (!sysConfigChangeobj) {
-        return SET_ERROR(ERR_NCX_DEF_NOT_FOUND);
-    }
-
-    sysCapabilityChangeobj = 
-        ncx_find_object(sysmod,
-                        system_N_sysCapabilityChange);
-    if (!sysCapabilityChangeobj) {
-        return SET_ERROR(ERR_NCX_DEF_NOT_FOUND);
-    }
-
-    sysSessionStartobj = 
-        ncx_find_object(sysmod,
-                        system_N_sysSessionStart);
-    if (!sysSessionStartobj) {
-        return SET_ERROR(ERR_NCX_DEF_NOT_FOUND);
-    }
-
-    sysSessionEndobj = 
-        ncx_find_object(sysmod,
-                        system_N_sysSessionEnd);
-    if (!sysSessionEndobj) {
-        return SET_ERROR(ERR_NCX_DEF_NOT_FOUND);
-    }
-
-    sysConfirmedCommitobj = 
-        ncx_find_object(sysmod,
-                        system_N_sysConfirmedCommit);
-    if (!sysConfirmedCommitobj) {
-        return SET_ERROR(ERR_NCX_DEF_NOT_FOUND);
-    }
-
     /* set up set-log-level RPC operation */
     res = agt_rpc_register_method(AGT_SYS_MODULE,
                                   system_N_set_log_level,
@@ -871,9 +859,9 @@ void
 
 
 /********************************************************************
-* FUNCTION agt_sys_send_sysSessionStart
+* FUNCTION agt_sys_send_netconf_session_start
 *
-* Queue the <sysSessionStart> notification
+* Queue the <netconf-session-start> notification
 *
 * INPUTS:
 *   scb == session control block to use for payload values
@@ -883,31 +871,37 @@ void
 *
 *********************************************************************/
 void
-    agt_sys_send_sysSessionStart (const ses_cb_t *scb)
+    agt_sys_send_netconf_session_start (const ses_cb_t *scb)
 {
     agt_not_msg_t         *not;
+    obj_template_t        *netconf_session_start_obj;
 
     if (LOGDEBUG) {
-        log_debug("\nagt_sys: generating <sysSessionStart> "
+        log_debug("\nagt_sys: generating <netconf-session-start> "
                   "notification");
     }
 
-    not = agt_not_new_notification(sysSessionStartobj);
+    netconf_session_start_obj = 
+        ncx_find_object(ietf_netconf_notifications_mod,
+                        "netconf-session-start");
+    assert(netconf_session_start_obj);
+
+    not = agt_not_new_notification(netconf_session_start_obj);
     if (!not) {
         log_error("\nError: malloc failed; cannot "
-                  "send <sysSessionStartup>");
+                  "send <netconf-session-start>");
         return;
     }
 
-    add_common_session_parms(scb, not);
+    netconf_notifications_add_common_session_parms(scb, not, NULL /*parent_val*/);
 
     agt_not_queue_notification(not);
 
-} /* agt_sys_send_sysSessionStart */
+} /* agt_sys_send_netconf_session_start */
 
 
 /********************************************************************
-* FUNCTION getTermReasonStr
+* FUNCTION get_termination_reason_str
 *
 * Convert the termination reason enum to a string
 *
@@ -919,7 +913,7 @@ void
 *
 *********************************************************************/
 static const xmlChar*
-    getTermReasonStr ( ses_term_reason_t termreason)
+    get_termination_reason_str ( ses_term_reason_t termreason)
 {
     const xmlChar         *termreasonstr;
 
@@ -943,12 +937,10 @@ static const xmlChar*
     case SES_TR_OTHER:
         termreasonstr = (const xmlChar *)"other";
         break;
-    case SES_TR_BAD_START:
-        termreasonstr = (const xmlChar *)"bad-start";
-        break;
     case SES_TR_BAD_HELLO:
         termreasonstr = (const xmlChar *)"bad-hello";
         break;
+    case SES_TR_BAD_START:
     default:
         SET_ERROR(ERR_INTERNAL_VAL);
         termreasonstr = (const xmlChar *)"other";
@@ -959,14 +951,14 @@ static const xmlChar*
 
 
 /********************************************************************
-* FUNCTION agt_sys_send_sysSessionEnd
+* FUNCTION agt_sys_send_netconf_session_end
 *
-* Queue the <sysSessionEnd> notification
+* Queue the <netconf-session-end> notification
 *
 * INPUTS:
 *   scb == session control block to use for payload values
-*   termreason == enum for the terminationReason leaf
-*   killedby == session-id for killedBy leaf if termreason == "killed"
+*   termreason == enum for the termination-reason leaf
+*   killedby == session-id for killed-by leaf if termination_reason == "killed"
 *               ignored otherwise
 *
 * OUTPUTS:
@@ -974,61 +966,61 @@ static const xmlChar*
 *
 *********************************************************************/
 void
-    agt_sys_send_sysSessionEnd (const ses_cb_t *scb,
-                                ses_term_reason_t termreason,
-                                ses_id_t killedby)
+    agt_sys_send_netconf_session_end(const ses_cb_t *scb,
+                                ses_term_reason_t termination_reason,
+                                ses_id_t killed_by)
 {
     agt_not_msg_t         *not;
     val_value_t           *leafval;
-    const xmlChar         *termreasonstr;
+    const xmlChar         *termination_reason_str;
     status_t               res;
 
-    assert(scb && "agt_sys_send_sysSessionEnd() - param scb is NULL");
+    obj_template_t        *netconf_session_end_obj;
 
-    log_debug("\nagt_sys: generating <sysSessionEnd> notification");
 
-    not = agt_not_new_notification(sysSessionEndobj);
-    if (!not) {
-        log_error("\nError: malloc failed; cannot send <sysSessionEnd>");
-        return;
-    }
+    assert(scb && "agt_sys_send_netconf_session_end() - param scb is NULL");
+
+    log_debug("\nagt_sys: generating <netconf-session-end> notification");
+
+    netconf_session_end_obj = 
+        ncx_find_object(ietf_netconf_notifications_mod,
+                        "netconf-session-end");
+    assert(netconf_session_end_obj);
+
+    not = agt_not_new_notification(netconf_session_end_obj);
+    assert(not);
 
     /* session started;  not just being killed
      * in the <ncxconnect> message handler */
-    if (termreason != SES_TR_BAD_START) {
-        add_common_session_parms(scb, not);
+    if (termination_reason != SES_TR_BAD_START) {
+        netconf_notifications_add_common_session_parms(scb, not, NULL /*parent_val*/);
     }
 
     /* add sysSessionEnd/killedBy */
-    if (termreason == SES_TR_KILLED) {
-        leafval = agt_make_uint_leaf( sysSessionEndobj, system_N_killedBy, 
-                                      killedby, &res );
-        if (leafval) {
-            agt_not_add_to_payload(not, leafval);
-        } else {
-            payload_error(system_N_killedBy, res);
-        }
+    if (termination_reason == SES_TR_KILLED) {
+        leafval = agt_make_uint_leaf( netconf_session_end_obj, "killed-by", 
+                                      killed_by, &res );
+        assert(leafval);
+        agt_not_add_to_payload(not, leafval);
     }
 
     /* add sysSessionEnd/terminationReason */
-    termreasonstr = getTermReasonStr(termreason);
-    leafval = agt_make_leaf( sysSessionEndobj, system_N_terminationReason, 
-                             termreasonstr, &res );
-    if (leafval) {
-        agt_not_add_to_payload(not, leafval);
-    } else {
-        payload_error(system_N_terminationReason, res);
-    }
+    termination_reason_str = get_termination_reason_str(termination_reason);
+    leafval = agt_make_leaf( netconf_session_end_obj, "termination-reason", 
+                             termination_reason_str, &res );
+    assert(leafval);
+
+    agt_not_add_to_payload(not, leafval);
 
     agt_not_queue_notification(not);
-} /* agt_sys_send_sysSessionEnd */
+} /* agt_sys_send_netconf_session_end */
 
 
 
 /********************************************************************
-* FUNCTION agt_sys_send_sysConfigChange
+* FUNCTION agt_sys_send_netconf_config_change
 *
-* Queue the <sysConfigChange> notification
+* Queue the <netconf-config-change> notification
 *
 * INPUTS:
 *   scb == session control block to use for payload values
@@ -1040,12 +1032,13 @@ void
 *
 *********************************************************************/
 void
-    agt_sys_send_sysConfigChange (const ses_cb_t *scb,
+    agt_sys_send_netconf_config_change (const ses_cb_t *scb,
                                   dlq_hdr_t *auditrecQ)
 {
     agt_not_msg_t         *not;
     agt_cfg_audit_rec_t   *auditrec;
     val_value_t           *leafval, *listval;
+    obj_template_t        *netconf_config_change_obj; 
     obj_template_t        *listobj;
     status_t               res;
 
@@ -1057,22 +1050,37 @@ void
 #endif
 
     if (LOGDEBUG) {
-        log_debug("\nagt_sys: generating <sysConfigChange> "
+        log_debug("\nagt_sys: generating <netconf-config-change> "
                   "notification");
     }
+    netconf_config_change_obj =
+        ncx_find_object(ietf_netconf_notifications_mod,
+                        "netconf-config-change");
+    assert(netconf_config_change_obj);
+
+    not = agt_not_new_notification(netconf_config_change_obj);
+    assert(not);
+    {
+        obj_template_t  *changed_by_obj;
+        val_value_t     *changed_by_val;
+
+        changed_by_obj = 
+            obj_find_child(not->notobj,
+                            "ietf-netconf-notifications",
+                            "changed-by");
+        assert(changed_by_obj);
+        changed_by_val = val_new_value();
+        val_init_from_template(changed_by_val, changed_by_obj);
+
+
+        netconf_notifications_add_common_session_parms(scb, NULL /*not*/, changed_by_val);
+        agt_not_add_to_payload(not, changed_by_val);
 
-    not = agt_not_new_notification(sysConfigChangeobj);
-    if (!not) {
-        log_error("\nError: malloc failed; cannot "
-                  "send <sysConfigChange>");
-        return;
     }
 
-    add_common_session_parms(scb, not);
-
-    listobj = obj_find_child(sysConfigChangeobj,
-                             AGT_SYS_MODULE,
-                             system_N_edit);
+    listobj = obj_find_child(netconf_config_change_obj,
+                             "ietf-netconf-notifications",
+                             "edit");
     if (listobj == NULL) {
         SET_ERROR(ERR_NCX_DEF_NOT_FOUND);
     } else {
@@ -1080,53 +1088,46 @@ void
              auditrec != NULL;
              auditrec = (agt_cfg_audit_rec_t *)dlq_nextEntry(auditrec)) {
 
-            /* add sysConfigChange/edit */
+            /* add netconf-config-change/edit */
             listval = val_new_value();
-            if (listval == NULL) {
-                payload_error(system_N_edit, ERR_INTERNAL_MEM);
-            } else {
+            assert(listval != NULL);
+            {
                 val_init_from_template(listval, listobj);
 
                 /* pass off listval malloc here */
                 agt_not_add_to_payload(not, listval);            
 
-                /* add sysConfigChange/edit/target */
+                /* add netconf-config-change/edit/target */
                 leafval = agt_make_leaf(listobj,
-                                        system_N_target,
+                                        "target",
                                         auditrec->target,
                                         &res);
-                if (leafval) {
-                    val_add_child(leafval, listval);
-                } else {
-                    payload_error(system_N_target, res);
-                }
+                assert(leafval);
+                val_add_child(leafval, listval);
 
-                /* add sysConfigChange/edit/operation */
+                /* add netconf-config-change/edit/operation */
                 leafval = agt_make_leaf(listobj,
-                                        system_N_operation,
+                                        "operation",
                                         op_editop_name(auditrec->editop),
                                         &res);
-                if (leafval) {
-                    val_add_child(leafval, listval);
-                } else {
-                    payload_error(system_N_operation, res);
-                }
+                assert(leafval);
+                val_add_child(leafval, listval);
             }
         }
     }
 
     agt_not_queue_notification(not);
 
-} /* agt_sys_send_sysConfigChange */
+} /* agt_sys_send_netconf_config_change */
 
 
 /********************************************************************
-* FUNCTION agt_sys_send_sysCapabilityChange
+* FUNCTION agt_sys_send_netconf_capablity_change
 *
-* Send a <sysCapabilityChange> event for a module
+* Send a <netconf-capability-change> event for a module
 * being added
 *
-* Queue the <sysCapabilityChange> notification
+* Queue the <netconf-capability-change> notification
 *
 * INPUTS:
 *   changed_by == session control block that made the
@@ -1141,13 +1142,13 @@ void
 *
 *********************************************************************/
 void
-    agt_sys_send_sysCapabilityChange (ses_cb_t *changed_by,
+    agt_sys_send_netconf_capability_change (ses_cb_t *changed_by,
                                       boolean is_add,
                                       const xmlChar *capstr)
 {
     agt_not_msg_t         *not;
-    val_value_t           *changedbyval, *leafval;
-    obj_template_t        *changedbyobj;
+    obj_template_t        *netconf_capability_change_obj;
+    val_value_t           *leafval;
     status_t               res;
 
 #ifdef DEBUG
@@ -1158,113 +1159,69 @@ void
 #endif
 
     if (LOGDEBUG) {
-        log_debug("\nagt_sys: generating <sysCapabilityChange> "
+        log_debug("\nagt_sys: generating <netconf-capability-change> "
                   "notification");
     }
 
-    changedbyobj = obj_find_child(sysCapabilityChangeobj,
-                                  AGT_SYS_MODULE,
-                                  system_N_changed_by);
-    if (!changedbyobj) {
-        SET_ERROR(ERR_NCX_DEF_NOT_FOUND);
-        return;
-    }
+    netconf_capability_change_obj =
+        ncx_find_object(ietf_netconf_notifications_mod,
+                        "netconf-capability-change");
+    assert(netconf_capability_change_obj);
 
-    not = agt_not_new_notification(sysCapabilityChangeobj);
-    if (!not) {
-        log_error("\nError: malloc failed; cannot "
-                  "send <sysCapabilityChange>");
-        return;
-    }
+    not = agt_not_new_notification(netconf_capability_change_obj);
+    assert(not);
 
-    changedbyval = val_new_value();
-    if (!changedbyval) {
-        log_error("\nError: malloc failed; cannot "
-                  "send <sysCapabilityChange>");
-        agt_not_free_notification(not);
-        return;
-    }
-    val_init_from_template(changedbyval, changedbyobj);
-    agt_not_add_to_payload(not, changedbyval);
+    {
+        obj_template_t  *changed_by_obj;
+        val_value_t     *changed_by_val;
 
-    if (changed_by) {
-        /* add userName */
-        if (changed_by->username) {
-            leafval = agt_make_leaf(changedbyobj,
-                                    system_N_userName,
-                                    changed_by->username,
-                                    &res);
-            if (leafval) {
-                val_add_child(leafval, changedbyval);
-            } else {
-                payload_error(system_N_userName, res);
-            }
-        }
+        changed_by_obj = 
+            obj_find_child(not->notobj,
+                            "ietf-netconf-notifications",
+                            "changed-by");
+        assert(changed_by_obj);
+        changed_by_val = val_new_value();
+        val_init_from_template(changed_by_val, changed_by_obj);
 
-        /* add sessionId */
-        leafval = agt_make_uint_leaf(changedbyobj,
-                                     system_N_sessionId,
-                                     changed_by->sid,
-                                     &res);
-        if (leafval) {
-            val_add_child(leafval, changedbyval);
+        if(changed_by) {
+            netconf_notifications_add_common_session_parms(changed_by, NULL /*not*/, changed_by_val);
         } else {
-            payload_error(system_N_sessionId, res);
-        }
-
-        /* add remoteHost */
-        if (changed_by->peeraddr) {
-            leafval = agt_make_leaf(changedbyobj,
-                                    system_N_remoteHost,
-                                    changed_by->peeraddr,
+            leafval = agt_make_leaf(changed_by_obj,
+                                    "server",
+                                    NULL,
                                     &res);
-            if (leafval) {
-                val_add_child(leafval, changedbyval);
-            } else {
-                payload_error(system_N_remoteHost, res);
-            }
-        }
-    } else {
-        leafval = agt_make_leaf(changedbyobj,
-                                NCX_EL_SERVER,
-                                NULL,
-                                &res);
-        if (leafval) {
-            val_add_child(leafval, changedbyval);
-        } else {
-            payload_error(NCX_EL_SERVER, res);
+            assert(leafval);
+            val_add_child(leafval, changed_by_val);
         }
+        agt_not_add_to_payload(not, changed_by_val);
+
     }
 
     if (is_add) {
-        /* add sysCapoabilityChange/added-capability */
-        leafval = agt_make_leaf(sysCapabilityChangeobj,
-                                system_N_added_capability,
+        /* add netconf-capability-change/added-capability */
+        leafval = agt_make_leaf(netconf_capability_change_obj,
+                                "added-capability",
                                 capstr,
                                 &res);
     } else {
-        /* add sysCapoabilityChange/deleted-capability */
-        leafval = agt_make_leaf(sysCapabilityChangeobj,
-                                system_N_deleted_capability,
+        /* add netconf-capability-change/deleted-capability */
+        leafval = agt_make_leaf(netconf_capability_change_obj,
+                                "deleted-capability",
                                 capstr,
                                 &res);
     }
-    if (leafval) {
-        agt_not_add_to_payload(not, leafval);
-    } else {
-        payload_error(is_add ? system_N_added_capability :
-                      system_N_deleted_capability, res);
-    }
+    assert(leafval);
+    agt_not_add_to_payload(not, leafval);
 
     agt_not_queue_notification(not);
 
-} /* agt_sys_send_sysCapabilityChange */
+} /* agt_sys_send_netconf_capability_change */
 
 
 /********************************************************************
-* FUNCTION agt_sys_send_sysConfirmedCommit
+* FUNCTION agt_sys_send_netconf_confirmed_commit
 *
-* Queue the <sysConfirmedCommit> notification
+* Queue the <netconf-confirmed-commit> notification
 *
 * INPUTS:
 *   scb == session control block to use for payload values
@@ -1275,10 +1232,11 @@ void
 *
 *********************************************************************/
 void
-    agt_sys_send_sysConfirmedCommit (const ses_cb_t *scb,
+    agt_sys_send_netconf_confirmed_commit (const ses_cb_t *scb,
                                      ncx_confirm_event_t event)
 {
     agt_not_msg_t         *not;
+    obj_template_t        *netconf_confirmed_commit_obj;
     val_value_t           *leafval;
     const xmlChar         *eventstr;
     status_t               res;
@@ -1293,36 +1251,35 @@ void
     }
 
     if (LOGDEBUG) {
-        log_debug("\nagt_sys: generating <sysConfirmedCommit> "
+        log_debug("\nagt_sys: generating <netconf-confirmed-commit> "
                   "notification (%s)",
                   eventstr);
     }
 
-    not = agt_not_new_notification(sysConfirmedCommitobj);
-    if (!not) {
-        log_error("\nError: malloc failed; cannot "
-                  "send <sysConfirmedCommit>");
-        return;
-    }
+    netconf_confirmed_commit_obj =
+        ncx_find_object(ietf_netconf_notifications_mod,
+                        "netconf-confirmed-commit");
+    assert(netconf_confirmed_commit_obj);
 
-    if (scb) {
-        add_common_session_parms(scb, not);
+    not = agt_not_new_notification(netconf_confirmed_commit_obj);
+    assert(not);
+
+    if (event!=NCX_CC_EVENT_TIMEOUT) {
+        assert(scb);
+        netconf_notifications_add_common_session_parms(scb, not, NULL /*changed_by_val*/);
     }
 
     /* add sysConfirmedCommit/confirmEvent */
-    leafval = agt_make_leaf(sysConfirmedCommitobj,
-                            system_N_confirmEvent,
+    leafval = agt_make_leaf(netconf_confirmed_commit_obj,
+                            "confirm-event",
                             eventstr,
                             &res);
-    if (leafval) {
-        agt_not_add_to_payload(not, leafval);
-    } else {
-        payload_error(system_N_confirmEvent, res);
-    }
+    assert(leafval);
+    agt_not_add_to_payload(not, leafval);
 
     agt_not_queue_notification(not);
 
-} /* agt_sys_send_sysConfirmedCommit */
+} /* agt_sys_send_netconf_confirmed_commit */
 
 
 
