@@ -43,63 +43,22 @@ date         init     comment
 #include  <stdlib.h>
 #include  <string.h>
 #include  <memory.h>
+#include  <assert.h>
 
-#ifndef _H_procdefs
 #include  "procdefs.h"
-#endif
-
-#ifndef _H_cap
 #include  "cap.h"
-#endif
-
-#ifndef _H_dlq
 #include  "dlq.h"
-#endif
-
-#ifndef _H_log
 #include  "log.h"
-#endif
-
-#ifndef _H_ncx
 #include  "ncx.h"
-#endif
-
-#ifndef _H_ncx_feature
 #include  "ncx_feature.h"
-#endif
-
-#ifndef _H_ncx_list
 #include  "ncx_list.h"
-#endif
-
-#ifndef _H_ncxconst
 #include  "ncxconst.h"
-#endif
-
-#ifndef _H_ncxtypes
 #include  "ncxtypes.h"
-#endif
-
-#ifndef _H_status
 #include  "status.h"
-#endif
-
-#ifndef _H_xmlns
 #include  "xmlns.h"
-#endif
-
-#ifndef _H_xml_util
 #include  "xml_util.h"
-#endif
-
-#ifndef _H_xml_val
 #include  "xml_val.h"
-#endif
-
-#ifndef _H_yangconst
 #include  "yangconst.h"
-#endif
-
 /********************************************************************
 *                                                                   *
 *                       C O N S T A N T S                           *
@@ -151,6 +110,7 @@ static cap_stdrec_t stdcaps[] =
   { CAP_STDID_V11, CAP_BIT_V11, CAP_NAME_V11 },
   { CAP_STDID_VALIDATE11, CAP_BIT_VALIDATE11, CAP_NAME_VALIDATE11 },
   { CAP_STDID_CONF_COMMIT11, CAP_BIT_CONF_COMMIT11, CAP_NAME_CONF_COMMIT11 },
+  { CAP_STDID_YANG_LIBRARY, CAP_BIT_YANG_LIBRARY, CAP_NAME_YANG_LIBRARY },
   { CAP_STDID_LAST_MARKER, 0x0, 
     (const xmlChar *)"" } /* end-of-list marker */
 };
@@ -792,7 +752,7 @@ status_t
     const xmlChar *str;
     uint32         caplen, namelen, schemelen, basiclen;
     cap_stdid_t    stdid;
-
+    status_t       res;
 #ifdef DEBUG
     if (!caplist || !uri) {
         return SET_ERROR(ERR_INTERNAL_PTR);
@@ -893,6 +853,43 @@ status_t
                 }
             }
             break;
+        case CAP_STDID_YANG_LIBRARY:
+            namelen = xml_strlen(stdcaps[stdid].cap_name);
+            if (!xml_strncmp(str, stdcaps[stdid].cap_name,
+                             namelen)) {
+
+                char* params_str;
+                char* revision_str;
+                char* module_set_id_str;
+                int i;
+
+                /* parsing ?revision=2016-06-21&module-set-id=.. */
+                str += namelen;
+
+                params_str=strdup(str);
+
+
+                revision_str = strstr(params_str,CAP_REVISION_EQ);
+                module_set_id_str = strstr(params_str,CAP_MODULE_SET_ID_EQ);
+
+                for(i=0;params_str[i]!=0;i++) {
+                    if(params_str[i]=='&') params_str[i]=0;
+                }
+
+
+                if(params_str[0]!='?' ||
+                   revision_str==NULL ||
+                   module_set_id_str==NULL ||
+                   strlen(revision_str)!=(strlen(CAP_REVISION_EQ)+strlen("2017-07-28")) ||
+                   strlen(module_set_id_str)<=strlen(CAP_MODULE_SET_ID_EQ)
+                   ) {
+                    log_warn("Warning: Bad yang-library:1.0 capability uri: %s\n", uri);
+                }
+                res=cap_add_std(caplist, stdid);
+                free(params_str);
+                return res;
+            }
+            break;
         default:
             if (!xml_strcmp(str, stdcaps[stdid].cap_name)) {
                 return cap_add_std(caplist, stdid);
@@ -1483,6 +1480,86 @@ status_t
 
 }  /* cap_add_withdefval */
 
+/********************************************************************
+* FUNCTION cap_add_yang_library_val
+*
+* Add the :yang-library:1.0 capability to the list
+* value struct version
+*
+* INPUTS:
+*    caplist == capability list that will contain the standard cap
+*    revision == the basic-mode with-default style
+*    module_set_id == the module_set_id hash
+*
+* OUTPUTS:
+*    status
+*********************************************************************/
+status_t
+    cap_add_yang_library_val (val_value_t *caplist,
+                        const xmlChar *revision,
+                        const xmlChar *module_set_id)
+{
+    char* format = "urn:ietf:params:netconf:capability:yang-library:1.0?revision=%s&module-set-id=%s";
+    val_value_t          *capval;
+    char*                 buf;
+
+    assert(caplist && revision && module_set_id);
+
+    /* setup the string */
+    buf = (char*)malloc(strlen(format)+strlen(revision)+strlen(module_set_id)+1);
+    assert(buf);
+    sprintf(buf,format,revision,module_set_id);
+
+    /* make the capability element */
+    capval = xml_val_new_string(NCX_EL_CAPABILITY,
+                                xmlns_nc_id(),
+                                buf);
+
+    val_add_child(capval, caplist);
+    return NO_ERR;
+
+}  /* cap_add_yang_library_val */
+
+/********************************************************************
+* FUNCTION cap_update_yang_library_val
+*
+* Update the :yang-library:1.0 capability
+* value struct version
+*
+* INPUTS:
+*    caplist == capability list that will contain the standard cap
+*    revision == the basic-mode with-default style
+*    module_set_id == the module_set_id hash
+*
+* OUTPUTS:
+*    status
+*********************************************************************/
+status_t
+    cap_update_yang_library_val (val_value_t *caplist,
+                        const xmlChar *revision,
+                        const xmlChar *module_set_id)
+{
+    char* prefix = "urn:ietf:params:netconf:capability:yang-library:1.0";
+    int prefixlen = strlen(prefix);
+    val_value_t* childval;
+    for (childval = val_get_first_child(caplist);
+        childval != NULL;
+        childval = val_get_next_child(childval)) {
+        if(strlen(VAL_STRING(childval))<prefixlen) {
+            continue;
+        }
+        if(0==memcmp(prefix,VAL_STRING(childval),strlen(prefix))) {
+            break;
+        }
+    }
+    if(childval)
+    {
+        val_remove_child(childval);
+        val_free_value(childval);
+    }
+    return cap_add_yang_library_val (caplist, revision, module_set_id);
+}  /* cap_update_yang_library_val */
+
 
 /********************************************************************
 * FUNCTION cap_add_ent
