@@ -41,6 +41,7 @@ date         init     comment
 #include <string.h>
 #include <ctype.h>
 #include <xmlstring.h>
+#include <assert.h>
 
 #include  "procdefs.h"
 #include "cfg.h"
@@ -56,6 +57,7 @@ date         init     comment
 #include "var.h"
 #include "xml_util.h"
 #include "yangconst.h"
+#include "val123.h"
 
 
 /********************************************************************
@@ -639,7 +641,6 @@ static char *
 
 } /* copy_argv_to_buffer */
 
-
 /**************    E X T E R N A L   F U N C T I O N S **********/
 
 
@@ -1128,7 +1129,7 @@ val_value_t *
     char           *parmname, *parmval;
     char           *str = NULL, *buff, testch;
     int32           buffpos, bufflen;
-    uint32          parmnamelen, copylen, matchcount;
+    uint32          parmnamelen;
     ncx_btype_t     btyp;
     status_t        res;
     xmlChar         errbuff[ERRLEN+1], savechar;
@@ -1294,46 +1295,63 @@ val_value_t *
          * check for the end of the parm name, wsp or equal sign
          * get the parm template, and get ready to parse it
          */
+
         if (res == NO_ERR) {
-            /* check the parmname string for a terminating char */
-            parmname = &buff[buffpos];
-            parmnamelen = 0;
+            unsigned int offset=0;
+            unsigned int len;
+            obj_template_t* base_obj = obj;
 
-            if (ncx_valid_fname_ch(*parmname)) {
-                str = &parmname[1];
-                while (*str && ncx_valid_name_ch(*str)) {
-                    str++;
+            do {
+                res = cli123_parse_next_child_obj_from_path(base_obj, autocomp, &buff[buffpos+offset], &len, &chobj);
+
+                if(res!=NO_ERR || chobj==NULL) {
+                    break;
                 }
-                parmnamelen = (uint32)(str - parmname);
-                copylen = parmnamelen;
-
-                /* check if this parameter name is in the parmset def */
-                chobj = obj_find_child_str(obj, NULL, 
-                                           (const xmlChar *)parmname,
-                                           parmnamelen);
-
-                /* check if parm was found, try partial name if not */
-                if (!chobj && autocomp) {
-                    matchcount = 0;
-                    chobj = obj_match_child_str(obj, NULL,
-                                                (const xmlChar *)parmname,
-                                                parmnamelen,
-                                                &matchcount);
-                    if (chobj) {
-                        gotmatch = TRUE;
-                        if (matchcount > 1) {
-                            res = ERR_NCX_AMBIGUOUS_CMD;
+                offset += len;
+                if(chobj->objtype==OBJ_TYP_LIST && buff[buffpos+offset]=='[') {
+                    while (buff[buffpos+offset]=='[') {
+                        /* key predicates e.g. /a/b[c=1][d=2] */
+                        val_value_t* predicate_val;
+                        unsigned int predicate_len;
+                        offset++;
+                        res = cli123_parse_parm_assignment(chobj, autocomp, &buff[buffpos+offset], &predicate_len, &predicate_val);
+                        if(res != NO_ERR) {
+                            break;
                         }
-                    } else {
-                        copylen = 0;
+                        val_free_value(predicate_val);
+                        offset += predicate_len;
+                        if(buff[buffpos+offset]!=']') {
+                            res = ERR_NCX_INVALID_VALUE;
+                            break;
+                        }
+                        offset++;
                     }
                 }
 
-                /* advance the buffer pointer */
-                buffpos += copylen;
+                if(res!=NO_ERR) {
+                    break;
+                }
 
-            }  /* else it could be a default-parm value */
+                if((chobj->objtype==OBJ_TYP_CONTAINER || chobj->objtype==OBJ_TYP_LIST) && buff[buffpos+offset]=='/') {
+                    /* instance-identifier to parameter in subcontainer e.g. foo/bar[name='123']/leaf=123*/
+                    base_obj=chobj;
+                    offset++;
+                    continue;
+                }
 
+                parmname=&buff[buffpos];
+                parmnamelen=offset;
+                buffpos += offset;
+                break;
+            } while(1);
+
+            if(res==NO_ERR && chobj!=NULL) {
+                gotmatch=TRUE;
+            }
+
+            if(res==ERR_NCX_AMBIGUOUS_CMD) {
+                gotmatch=TRUE;
+            }
 
             if (res != NO_ERR) {
                 if (res == ERR_NCX_INVALID_VALUE) {
@@ -1567,8 +1585,11 @@ val_value_t *
 
         /* create a new val_value struct and set the value */
         if (res == NO_ERR) {
-            res = parse_cli_parm(rcxt, val, chobj, 
-                                 (const xmlChar *)parmval, script);
+            char* instance_id_str;
+            instance_id_str = strndup(parmname, parmnamelen);
+            assert(instance_id_str);
+            res = cli123_parse_value_instance(rcxt, val, chobj, instance_id_str, (const xmlChar *)parmval, script);
+            free(instance_id_str);
         } else if (res == ERR_NCX_EMPTY_VAL &&
                    gotmatch && !gotdashes) {
             /* matched parm did not work out so
@@ -1579,8 +1600,7 @@ val_value_t *
             if (chobj) {
                 savechar = parmname[parmnamelen];
                 parmname[parmnamelen] = 0;
-                res = parse_cli_parm(rcxt, val, chobj, 
-                                     (const xmlChar *)parmname, script);
+                res = cli123_parse_value_instance(rcxt, val, chobj, obj_get_name(chobj)/*instance_id_str*/, (const xmlChar *)parmname, script);
                 parmname[parmnamelen] = savechar;
             }
         }
@@ -1592,6 +1612,9 @@ val_value_t *
             if (parmname != NULL) {
                 xml_strncpy(errbuff, (const xmlChar *)parmname, 
                             min(parmnamelen, ERRLEN));
+            } else {
+                xml_strncpy(errbuff, (const xmlChar *)&buff[buffpos],
+                            min(strlen(&buff[buffpos]), ERRLEN));
             }
             switch (res) {
             case ERR_NCX_UNKNOWN_PARM:
