@@ -554,6 +554,11 @@ typedef enum ncx_protocol_t_ {
     NCX_PROTO_NETCONF11       /* RFC xxxx base:1.1 */
 } ncx_protocol_t;
 
+typedef enum ncx_yang_version_t_ {
+    NCX_YANG_VERSION10,
+    NCX_YANG_VERSION11
+} ncx_yang_version_t;
+
 
 /* YANG feature entry */
 typedef struct ncx_feature_t_ {
@@ -581,7 +586,6 @@ typedef struct ncx_filptr_t_ {
     dlq_hdr_t             childQ;  /* Q of ncx_filptr_t */
 } ncx_filptr_t;
 
-
 /* back pointer to a YANG identity
  * used to create an inline tree of valid values
  * for an identity used as a base
@@ -600,31 +604,34 @@ typedef struct ncx_idlink_t_ {
     boolean    inq;
 } ncx_idlink_t;
 
-
 /* YANG identity entry */
 typedef struct ncx_identity_t_ {
     dlq_hdr_t             qhdr;
-    struct ncx_identity_t_ *base;      /* back-ptr to base id */
+    dlq_hdr_t             baseQ;
     xmlChar              *name;
-    xmlChar              *baseprefix;
-    xmlChar              *basename;
     xmlChar              *descr;
     xmlChar              *ref;
     ncx_status_t          status;
-    dlq_hdr_t             childQ;          /* Q of ncx_idlink_t */
     dlq_hdr_t             appinfoQ;       /* Q of ncx_appinfo_t */
     status_t              res;     /* may be stored with errors */
-    boolean               isroot;    /* base==NULL not an error */
-    ncx_idlink_t          idlink;
+    boolean               isroot;    /* empty baseQ not an error */
+    dlq_hdr_t             childQ;          /* Q of ncx_idlink_t */
     ncx_error_t           tkerr;
     boolean               seen;                  /* for yangcli */
 } ncx_identity_t;
 
+typedef struct ncx_identity_base_t_ {
+    dlq_hdr_t             qhdr;
+    xmlChar              *prefix;
+    xmlChar              *name;
+    ncx_identity_t       *identity;
+    ncx_idlink_t          idlink;
+} ncx_identity_base_t;
 
 /* representation of one module or submodule during and after parsing */
 typedef struct ncx_module_t_ {
     dlq_hdr_t         qhdr;
-    xmlChar          *name; 
+    xmlChar          *name;
     xmlChar          *version;
     xmlChar          *organization;
     xmlChar          *contact_info;
@@ -640,7 +647,7 @@ typedef struct ncx_module_t_ {
     const xmlChar    *belongsver;    /* back ptr to mod ver */
 
     xmlns_id_t        nsid;            /* assigned by xmlns */
-    uint32            langver;
+    ncx_yang_version_t langver;
     boolean           ismod;     /* module/submodule keyword */
     boolean           stmtmode;       /* T: save yang_stmt_t */
     boolean           added;         /* T: don't free on err */
@@ -675,6 +682,9 @@ typedef struct ncx_module_t_ {
 
     ncx_list_t        devmodlist;     /* for deviations list */
 
+   /* yang-library conformance-type {implement,import} */
+   boolean implemented;
+
 } ncx_module_t;
 
 
