@@ -65,8 +65,6 @@ date         init     comment
 #include "xpath1.h"
 #include "yangconst.h"
 
-#include "mgr_xml.c"
-
 /********************************************************************
 *                                                                   *
 *                       C O N S T A N T S                           *
@@ -123,7 +121,7 @@ static status_t
 {
     status_t   res;
 
-    res = mgr_xml_consume_node(scb->reader, xmlnode);
+    res = xml_consume_node(scb->reader, xmlnode, TRUE, TRUE);
     return res;
 
 }   /* get_xml_node */
@@ -245,7 +243,7 @@ static status_t
         /* at this point have either a simple type or a complex type
          * get the next node which could be any type 
          */
-        res = mgr_xml_consume_node_nons(scb->reader, &nextnode);
+        res = xml_consume_node(scb->reader, &nextnode, FALSE, TRUE);
     }
 
     if (res == NO_ERR) {
@@ -297,7 +295,7 @@ static status_t
     if (getstrend) {
         /* need to get the endnode for startnode then exit */
         xml_clean_node(&nextnode);
-        res2 = mgr_xml_consume_node_nons(scb->reader, &nextnode);
+        res2 = xml_consume_node(scb->reader, &nextnode, FALSE, TRUE);
         if (res2 == NO_ERR) {
 #ifdef MGR_VAL_PARSE_DEBUG
             if (LOGDEBUG4) {
@@ -367,7 +365,7 @@ static status_t
         }
 
         /* get the next node */
-        res = mgr_xml_consume_node_nons(scb->reader, &nextnode);
+        res = xml_consume_node(scb->reader, &nextnode, FALSE, TRUE);
         if (res == NO_ERR) {
 #ifdef MGR_VAL_PARSE_DEBUG
             if (LOGDEBUG4) {
@@ -1593,7 +1591,7 @@ static status_t
                 done = TRUE;
             } else {
                 /* skip the entire value subtree */
-                (void)mgr_xml_skip_subtree(scb->reader, startnode);
+                (void)xml_skip_subtree(scb->reader, startnode);
             }
             continue;
         }
