@@ -135,6 +135,13 @@ extern "C" {
 #define XP_FN_MODULE_LOADED        (const xmlChar *)"module-loaded"
 #define XP_FN_FEATURE_ENABLED      (const xmlChar *)"feature-enabled"
 
+/* YANG 1.1 functions */
+#define XP_FN_RE_MATCH             (const xmlChar *)"re-match"
+#define XP_FN_DERIVED_FROM         (const xmlChar *)"derived-from"
+#define XP_FN_DERIVED_FROM_OR_SELF (const xmlChar *)"derived-from-or-self"
+#define XP_FN_DEREF                (const xmlChar *)"deref"
+#define XP_FN_ENUM_VALUE           (const xmlChar *)"enum-value"
+#define XP_FN_BIT_IS_SET           (const xmlChar *)"bit-is-set"
 
 /* XPath NodeType values */
 #define XP_NT_COMMENT              (const xmlChar *)"comment"
