@@ -56,6 +56,7 @@ date         init     comment
 #include "tk.h"
 #include "typ.h"
 #include "val.h"
+#include "val_util.h"
 #include "xmlns.h"
 #include "xpath.h"
 #include "xpath_yang.h"
@@ -1846,7 +1847,7 @@ status_t
          * if obj is config, it can point at only config targobj
          * if obj not config, it can point at any targobj node
          */
-        if (obj_get_config_flag(obj) &&
+        if (mod && mod->langver<NCX_YANG_VERSION11 && obj_get_config_flag(obj) &&
             !obj_get_config_flag(pcb->targobj)) {
 
             doerror = TRUE;
@@ -2419,6 +2420,10 @@ val_value_t *
                 res = SET_ERROR(ERR_INTERNAL_VAL);
             }
         }
+
+        if(curtop->obj->objtype == OBJ_TYP_LIST) {
+            res = val_gen_index_chain(curtop->obj, curtop);
+        }
     }
 
 
