@@ -41,108 +41,135 @@ date         init     comment
 #include <errno.h>
 #include <stdio.h>
 #include <ctype.h>
+#include <assert.h>
 #include "libtecla.h"
 
-#ifndef _H_procdefs
 #include "procdefs.h"
-#endif
-
-#ifndef _H_log
 #include "log.h"
-#endif
-
-#ifndef _H_mgr
 #include "mgr.h"
-#endif
-
-#ifndef _H_mgr_ses
 #include "mgr_ses.h"
-#endif
-
-#ifndef _H_ncx
 #include "ncx.h"
-#endif
-
-#ifndef _H_ncx_feature
 #include "ncx_feature.h"
-#endif
-
-#ifndef _H_ncx_list
 #include "ncx_list.h"
-#endif
-
-#ifndef _H_ncxconst
 #include "ncxconst.h"
-#endif
-
-#ifndef _H_ncxmod
 #include "ncxmod.h"
-#endif
-
-#ifndef _H_obj
 #include "obj.h"
-#endif
-
-#ifndef _H_op
 #include "op.h"
-#endif
-
-#ifndef _H_rpc
 #include "rpc.h"
-#endif
-
-#ifndef _H_rpc_err
 #include "rpc_err.h"
-#endif
-
-#ifndef _H_status
 #include "status.h"
-#endif
-
-#ifndef _H_val_util
 #include "val_util.h"
-#endif
-
-#ifndef _H_var
 #include "var.h"
-#endif
-
-#ifndef _H_xmlns
 #include "xmlns.h"
-#endif
-
-#ifndef _H_xml_util
 #include "xml_util.h"
-#endif
-
-#ifndef _H_xml_val
 #include "xml_val.h"
-#endif
-
-#ifndef _H_yangconst
 #include "yangconst.h"
-#endif
-
-#ifndef _H_yangcli
 #include "yangcli.h"
-#endif
-
-#ifndef _H_yangcli_autoload
 #include "yangcli_autoload.h"
-#endif
-
-#ifndef _H_yangcli_cmd
 #include "yangcli_cmd.h"
-#endif
-
-#ifndef _H_yangcli_util
 #include "yangcli_util.h"
-#endif
+#include "yangcli_yang_library.h"
 
 #ifdef DEBUG
 #define YANGCLI_AUTOLOAD_DEBUG 1
 #endif
 
+/********************************************************************
+* FUNCTION make_get_schema_reqdata
+* 
+* Allocate and initialize reqdata value for <get-schema>
+*
+* format will be hard-wired to yang
+*
+* INPUTS:
+*   server_cb == server control block to use
+*   scb == session control block to use
+*   module == module to get
+*   revision == revision to get
+*
+* OUTPUTS:
+*    out_rpc == obj_template_t** of the get-schema RPC
+*    out_reqdata == val_value_t** of the get-schema data value
+*
+* RETURNS:
+*    status
+*********************************************************************/
+status_t make_get_schema_reqdata(server_cb_t *server_cb,
+                              ses_cb_t *scb,
+                              const xmlChar *module,
+                              const xmlChar *revision,
+                              obj_template_t** out_rpc,
+                              val_value_t** out_reqdata)
+{
+    ncx_module_t          *mod;
+    obj_template_t        *rpc, *input, *parmobj;
+    val_value_t           *reqdata, *parmval;
+    status_t               res;
+    xmlns_id_t             nsid;
+
+    reqdata = NULL;
+    res = NO_ERR;
+    input = NULL;
+    nsid = 0;
+    mod = ncx_find_module(NCXMOD_IETF_NETCONF_STATE, NULL);
+    if (mod == NULL) {
+        return SET_ERROR(ERR_NCX_DEF_NOT_FOUND);
+    }
+
+    /* get the <get-schema> input template */
+    rpc = ncx_find_rpc(mod,  NCX_EL_GET_SCHEMA);
+    assert(rpc);
+    nsid = obj_get_nsid(rpc);
+    input = obj_find_child(rpc, NULL, YANG_K_INPUT);
+    assert(input);
+
+    /* construct a method + parameter tree */
+    reqdata = val_new_value();
+    assert(reqdata);
+    val_init_from_template(reqdata, rpc);
+
+    /* add /get-schema/input/identifier */
+    parmobj = obj_find_child(input, NCXMOD_IETF_NETCONF_STATE, NCX_EL_IDENTIFIER);
+    assert(parmobj);
+    parmval = val_make_simval_obj(parmobj,
+                                  module,
+                                  &res);
+
+    assert(parmval);
+    val_add_child(parmval, reqdata);
+
+    /* add /get-schema/input/version */
+    parmobj = obj_find_child(input, NCXMOD_IETF_NETCONF_STATE, NCX_EL_VERSION);
+    assert(parmobj);
+    parmval = val_make_simval_obj(parmobj,
+                                  (revision) ? revision : EMPTY_STRING,
+                                  &res);
+
+    assert(parmval);
+    val_add_child(parmval, reqdata);
+
+    /* add /get-schema/input/format */
+    parmobj = obj_find_child(input, NCXMOD_IETF_NETCONF_STATE, NCX_EL_FORMAT);
+    assert(parmobj);
+    parmval = val_make_simval_obj(parmobj,
+                                  "yang",
+                                  &res);
+
+    assert(parmval);
+    val_add_child(parmval, reqdata);
+
+    /* check any errors so far */
+    if (res != NO_ERR) {
+        val_free_value(reqdata);
+        return res;
+    }
+
+    *out_rpc=rpc;
+    *out_reqdata=reqdata;
+
+    return res;
+
+} /* make_get_schema_reqdata */
 
 /********************************************************************
 * FUNCTION send_get_schema_to_server
@@ -152,7 +179,7 @@ date         init     comment
 *
 * format will be hard-wired to yang
 *
-* INPUTS:
+* INPUT:
 *   server_cb == server control block to use
 *   scb == session control block to use
 *   module == module to get
@@ -170,87 +197,16 @@ static status_t
                               const xmlChar *module,
                               const xmlChar *revision)
 {
-    ncx_module_t          *mod;
-    obj_template_t        *rpc, *input, *parmobj;
-    val_value_t           *reqdata, *parmval;
+    status_t              res;
+    obj_template_t*       rpc;
+    val_value_t*          reqdata;
     mgr_rpc_req_t         *req;
-    status_t               res;
-    xmlns_id_t             nsid;
 
     req = NULL;
-    reqdata = NULL;
-    res = NO_ERR;
-    input = NULL;
-    nsid = 0;
-    mod = ncx_find_module(NCXMOD_IETF_NETCONF_STATE, NULL);
-    if (mod == NULL) {
-        return SET_ERROR(ERR_NCX_DEF_NOT_FOUND);
-    }
 
-    /* get the <get-schema> input template */
-    rpc = ncx_find_rpc(mod,  NCX_EL_GET_SCHEMA);
-    if (rpc) {
-        nsid = obj_get_nsid(rpc);
-        input = obj_find_child(rpc, NULL, YANG_K_INPUT);
-    }
-
-    if (!input) {
-        res = SET_ERROR(ERR_NCX_DEF_NOT_FOUND);
-    } else {
-        /* construct a method + parameter tree */
-        reqdata = xml_val_new_struct(obj_get_name(rpc), 
-                                     nsid);
-        if (!reqdata) {
-            log_error("\nError allocating a new RPC request");
-            res = ERR_INTERNAL_MEM;
-        }
-    }
-
-    /* add /get-schema/input/identifier */
-    if (res == NO_ERR) {
-        parmval = xml_val_new_cstring(NCX_EL_IDENTIFIER,
-                                      nsid,
-                                      module);
-        if (parmval == NULL) {
-            res = ERR_INTERNAL_MEM;
-        } else {
-            val_add_child(parmval, reqdata);
-        }
-    }
-
-    /* add /get-schema/input/version */
-    if (res == NO_ERR) {
-        parmval = xml_val_new_cstring(NCX_EL_VERSION,
-                                      nsid,
-                                      (revision) ? revision : EMPTY_STRING);
-        if (parmval == NULL) {
-            res = ERR_INTERNAL_MEM;
-        } else {
-            val_add_child(parmval, reqdata);
-        }
-    }
-
-    /* add /get-schema/input/format */
-    if (res == NO_ERR) {
-        parmobj = obj_find_child(input,
-                                 NCXMOD_IETF_NETCONF_STATE,
-                                 NCX_EL_FORMAT);
-        if (parmobj == NULL) {
-            res = SET_ERROR(ERR_NCX_DEF_NOT_FOUND);
-        } else {
-            parmval = val_make_simval_obj(parmobj,
-                                          (const xmlChar *)"yang",
-                                          &res);
-            if (parmval != NULL) {
-                val_add_child(parmval, reqdata);
-            }
-        }
-    }
-
-    /* check any errors so far */
-    if (res != NO_ERR) {
-        val_free_value(reqdata);
-        return res;
+    res = make_get_schema_reqdata(server_cb, scb, module, revision, &rpc, &reqdata);
+    if(res!=NO_ERR) {
+        return NO_ERR;
     }
 
     /* allocate an RPC request and send it */
@@ -299,7 +255,6 @@ static status_t
 
 } /* send_get_schema_to_server */
 
-
 /********************************************************************
 * FUNCTION save_schema_file
 * 
@@ -412,28 +367,6 @@ static boolean
 
 }  /* reset_feature */
 
-
-/********************************************************************
- * FUNCTION copy_module_to_tempdir
- * 
- * Copy the source file to a different location and possibly
- * change the filename
- *
- * INPUTS:
- *   mscb == manager session control block to use
- *   module == module name to copy
- *   revision == revision date to copy
- *   isyang == TRUE if .yang extension needed
- *             FALSE if .yin extension needed
- *   res == address of return status
- *
- * OUTPUTS:
- *   *res == return status
- *
- * RETURNS:
- *   malloced and filled in temp file control block
- *   NULL if some error (see *res)
- *********************************************************************/
 static ncxmod_temp_filcb_t *
     get_new_temp_filcb (mgr_scb_t *mscb,
                         const xmlChar *module,
@@ -489,6 +422,43 @@ static ncxmod_temp_filcb_t *
 
 }   /* get_new_temp_filcb */
 
+status_t get_schema_reply_to_temp_filcb(server_cb_t * server_cb, mgr_scb_t *mscb, const xmlChar* module, const xmlChar* revision, val_value_t* reply)
+{
+    ncxmod_search_result_t  *searchresult;
+    ncxmod_temp_filcb_t     *temp_filcb;
+    val_value_t             *dataval;
+    status_t                 res;
+
+    /* get the data node out of the reply;
+     * it contains the requested YANG module
+     * in raw text form
+     */
+    dataval = val_find_child(reply, NULL, NCX_EL_DATA);
+    if (dataval == NULL) {
+        res = SET_ERROR(ERR_NCX_DATA_MISSING);
+    } else {
+        /* get a file handle in the temp session
+         * directory
+         */
+        temp_filcb = get_new_temp_filcb(mscb,
+                                        module,
+                                        revision,
+                                        TRUE,   /* isyang */
+                                        &res);
+        if (temp_filcb != NULL) {
+           /* copy the value node to the work directory
+            * as a YANG file
+            */
+            res = save_schema_file(server_cb,
+                                   module,
+                                   revision,
+                                   temp_filcb->source,
+                                   dataval);
+        }
+    }
+
+    return res;
+}
 
 /********************************************************************
  * FUNCTION copy_module_to_tempdir
@@ -550,7 +520,7 @@ static status_t
 #endif
 
     /* open the destination file for writing */
-    destfile = fopen((const char *)temp_filcb->source, "w");
+    destfile = fopen((const char *)temp_filcb->source, "w+");
     if (destfile == NULL) {
         res = errno_to_status();
         ncxmod_free_session_tempfile(temp_filcb);
@@ -1038,9 +1008,7 @@ status_t
 {
     mgr_scb_t               *mscb;
     ncxmod_search_result_t  *searchresult;
-    ncxmod_temp_filcb_t     *temp_filcb;
     const xmlChar           *module, *revision;
-    val_value_t             *dataval;
     status_t                 res;
     boolean                  done;
 
@@ -1054,6 +1022,21 @@ status_t
     res = NO_ERR;
     mscb = (mgr_scb_t *)scb->mgrcb;
     searchresult = server_cb->cursearchresult;
+
+    if(searchresult==NULL) {
+        /* check if this is yang-library <get> for /modules-state and add new searchresult entries */
+        res = get_yang_library_modules_state_reply_to_searchresult_entries(server_cb, scb, reply);
+        if (res == NO_ERR) {
+            searchresult = server_cb->cursearchresult;
+        } else {
+            assert(0);
+        }
+        if(searchresult==NULL) {
+            /* no search results left to get */
+            return autoload_compile_modules(server_cb, scb);
+        }
+    }
+
     module = searchresult->module;
     revision = searchresult->revision;
 
@@ -1078,34 +1061,7 @@ status_t
             }
         }
     } else {
-        /* get the data node out of the reply;
-         * it contains the requested YANG module
-         * in raw text form
-         */
-        dataval = val_find_child(reply, NULL, NCX_EL_DATA);
-        if (dataval == NULL) {
-            res = SET_ERROR(ERR_NCX_DATA_MISSING);
-        } else {
-            /* get a file handle in the temp session
-             * directory
-             */
-            temp_filcb = get_new_temp_filcb(mscb,
-                                            module,
-                                            revision,
-                                            TRUE,   /* isyang */
-                                            &res);
-            if (temp_filcb != NULL) {
-                /* copy the value node to the work directory
-                 * as a YANG file
-                 */
-                res = save_schema_file(server_cb,
-                                       module,
-                                       revision,
-                                       temp_filcb->source,
-                                       dataval);
-            }
-        }
-
+        res = get_schema_reply_to_temp_filcb(server_cb, mscb, module, revision, reply);
         if (res != NO_ERR) {
             log_error("\nError: save <get-schema> content "
                       " for module '%s' revision '%s' failed (%s)",
@@ -1114,6 +1070,7 @@ status_t
                       get_error_string(res));
             server_cb->cursearchresult->res = res;
         }
+
     }
 
     /* find next file that needs to be retrieved with get-schema */
@@ -1253,7 +1210,7 @@ status_t
      * the modules in order; all imports should already
      * be preloaded into the session work directory
      */
-    while (res == NO_ERR && 
+    while (/*res == NO_ERR && */
            !dlq_empty(&server_cb->searchresultQ)) {
 
         searchresult = (ncxmod_search_result_t *)
@@ -1270,10 +1227,16 @@ status_t
         }
 
         mod = NULL;
-        res = autoload_module(searchresult->module,
-                              searchresult->revision,
-                              &searchresult->cap->cap_deviation_list,
-                              &mod);
+        mod = ncx_find_module(searchresult->module,
+                              searchresult->revision);
+        if(mod==NULL) {
+            res = autoload_module(searchresult->module,
+                                  searchresult->revision,
+                                  searchresult->cap?&searchresult->cap->cap_deviation_list:NULL,
+                                  &mod);
+
+            searchresult->res = res;
+        }
 
         if (res == NO_ERR) {
             if (mod == NULL) {
@@ -1299,8 +1262,8 @@ status_t
                  * in the temp_modQ 
                  */
                 modptr = new_modptr(mod, 
-                                    &searchresult->cap->cap_feature_list,
-                                    &searchresult->cap->cap_deviation_list);
+                                    searchresult->cap?&searchresult->cap->cap_feature_list:NULL,
+                                    searchresult->cap?&searchresult->cap->cap_deviation_list:NULL);
                 if (modptr == NULL) {
                     log_error("\nMalloc failure");
                 } else {
