@@ -57,6 +57,7 @@ date         init     comment
 #include "rpc.h"
 #include "status.h"
 #include "val.h"
+#include "val123.h"
 #include "val_util.h"
 #include "var.h"
 #include "xml_util.h"
@@ -266,6 +267,28 @@ static status_t
     btyp = obj_get_basetype(parmobj);
 
     switch (btyp) {
+    case NCX_BT_IDREF:
+        {
+            const typ_idref_t *idref;
+            ncx_module_t *mod;
+            ncx_identity_t* identity;
+            idref = typ_get_cidref(typdef);
+
+            for (mod = ncx_get_first_session_module();
+                 mod != NULL;
+                 mod = ncx_get_next_session_module(mod)) {
+                 for(identity=(ncx_identity_t*)dlq_firstEntry(&mod->identityQ);
+                     identity!=NULL;
+                     identity=(ncx_identity_t*)dlq_nextEntry(identity)) {
+                     if(ncx123_identity_is_derived_from(identity, idref->base)) {
+                         res = fill_one_parm_completion(cpl, comstate, line,
+                                                        (const char *)identity->name,
+                                                        word_start, word_end, parmlen);
+                     }
+                 }
+            }
+        }
+	return res;
     case NCX_BT_ENUM:
     case NCX_BT_BITS:
         for (typenum = typ_first_enumdef(basetypdef);
@@ -293,8 +316,6 @@ static status_t
         return res;
     case NCX_BT_INSTANCE_ID:
         break;
-    case NCX_BT_IDREF:
-        break;
     default:
         break;
     }
@@ -320,6 +341,80 @@ static status_t
                                     int word_end,
                                     int cmdlen);
 
+
+/********************************************************************
+ * FUNCTION xpath_path_completion_common
+ *
+ * check and if obj is valid completion and register it with cpl_add_completion
+ *
+ * INPUTS:
+ *    obj == object template to check
+ *    cpl == word completion struct to fill in
+ *    line == line passed to callback
+ *    word_start == start position within line of the
+ *                  word being completed
+ *    word_end == word_end passed to callback
+ *    cmdlen == command length
+ *
+ * OUTPUTS:
+ *   cpl filled in if any matching commands found
+ *
+ * RETURNS:
+ *   status
+ *********************************************************************/
+
+static int xpath_path_completion_common(obj_template_t *rpc, obj_template_t * obj,
+                                    WordCompletion *cpl,
+                                    const char *line,
+                                    int word_start,
+                                    int word_end,
+                                    int cmdlen)
+{
+    int retval = 0;
+    xmlChar         *pathname;
+    do {
+        /* check if there is a partial command name */
+        if (cmdlen > 0 &&
+            strncmp((const char *)obj_get_name(obj),
+                    &line[word_start],
+                    cmdlen)) {
+            /* command start is not the same so skip it */
+            continue;
+        }
+
+        if( !obj_is_data_db(obj)) {
+            /* object is either rpc or notification*/
+            continue;
+        }
+
+        if(!obj_get_config_flag(obj)) {
+            const xmlChar* rpc_name;
+            rpc_name = obj_get_name(rpc);
+            if(0==strcmp((const char*)rpc_name, "create")) continue;
+            if(0==strcmp((const char*)rpc_name, "replace")) continue;
+            if(0==strcmp((const char*)rpc_name, "delete")) continue;
+        }
+
+        if(obj->objtype==OBJ_TYP_CONTAINER || obj->objtype==OBJ_TYP_LIST) {
+            pathname = malloc(strlen(obj_get_name(obj))+2);
+            assert(pathname);
+            strcpy(pathname, obj_get_name(obj));
+            pathname[strlen(obj_get_name(obj))] ='/';
+            pathname[strlen(obj_get_name(obj))+1] =0;
+        } else {
+            pathname = malloc(strlen(obj_get_name(obj))+1);
+            assert(pathname);
+            strcpy(pathname, obj_get_name(obj));
+            pathname[strlen(obj_get_name(obj))] =0;
+        }
+        retval = cpl_add_completion(cpl, line, word_start, word_end,
+                                    (const char *)&pathname[cmdlen], "", "");
+        free(pathname);
+    } while(0);
+
+    return retval;
+}
+
 /********************************************************************
  * FUNCTION fill_xpath_children_completion
  * 
@@ -348,16 +443,16 @@ static status_t
                                     int word_end,
                                     int cmdlen)
 {
-    const xmlChar         *pathname;
-    int                    retval;
+    int retval;
     int word_iter = word_start + 1;
     // line[word_start] == '/'
     word_start ++;
     cmdlen --;
     while(word_iter <= word_end) {
         if ((line[word_iter] == '/') || (line[word_iter] == '[')) {
-            // The second '/' or predicate condition starting with '[' is found
-            // find the top level obj and fill its child completion
+            /* The second '/' or predicate condition starting with '[' is found
+             * find the top level obj and fill its child completion
+             */
             char childName[128];
             int child_name_len = word_iter - word_start;
             strncpy (childName, &line[word_start], child_name_len);
@@ -368,10 +463,16 @@ static status_t
                 obj_find_child(parentObj,
                                NULL/*obj_get_mod_name(parentObj)*/,
                                (const xmlChar *)childName);
+            if(childObj==NULL) {
+            	/* no completion possible - the text before / or [ does not resolve to valid obj */
+            	return NO_ERR;
+            }
+
             cmdlen = word_end - word_iter;
 
-            // put the children path with topObj into the recursive 
-            // lookup function
+            /* put the children path with topObj into the recursive
+             * lookup function
+             */
             if(line[word_iter] == '/') {
                 return fill_xpath_children_completion(rpc, childObj,
                                                       cpl,line, word_iter,
@@ -386,31 +487,8 @@ static status_t
     }
     obj_template_t * childObj = obj_first_child_deep(parentObj);
     for(;childObj!=NULL; childObj = obj_next_child_deep(childObj)) {
-        pathname = obj_get_name(childObj);
-        /* check if there is a partial command name */
-        if (cmdlen > 0 &&
-            strncmp((const char *)pathname,
-                    &line[word_start],
-                    cmdlen)) {
-            /* command start is not the same so skip it */
-            continue;
-        }
 
-        if( !obj_is_data_db(childObj)) {
-            /* object is either rpc or notification*/
-            continue;
-        }
-
-        if(!obj_get_config_flag(childObj)) {
-            const xmlChar* rpc_name;
-            rpc_name = obj_get_name(rpc);
-            if(0==strcmp((const char*)rpc_name, "create")) continue;
-            if(0==strcmp((const char*)rpc_name, "replace")) continue;
-            if(0==strcmp((const char*)rpc_name, "delete")) continue;
-        }
-
-        retval = cpl_add_completion(cpl, line, word_start, word_end,
-                                    (const char *)&pathname[cmdlen], "", "");
+        retval = xpath_path_completion_common(rpc, childObj, cpl, line, word_start, word_end, cmdlen);
         if (retval != 0) {
             return ERR_NCX_OPERATION_FAILED;
         }
@@ -579,10 +657,13 @@ static obj_template_t *
                         int word_start,
                         int word_end)
 {
-    // line[word_end] == '/'
-    int cmdlen = (word_end - 1) - word_start;
+    int cmdlen = word_end - word_start;
     obj_template_t *modObj;
 
+    if(cmdlen==0) {
+        return NULL;
+    }
+
     if (use_servercb(comstate->server_cb)) {
         modptr_t *modptr;
         for (modptr = (modptr_t *)
@@ -653,38 +734,12 @@ static status_t
         int word_end,
         int cmdlen)
 {
+    int retval;
     obj_template_t * modObj = ncx_get_first_object(mod);
-    for (; modObj != NULL; 
+    for (; modObj != NULL;
          modObj = ncx_get_next_object(mod, modObj)) {
 
-        if (!obj_is_data_db(modObj)) {
-            /* object is either rpc or notification*/
-            continue;
-        }
-
-        const xmlChar *pathname = obj_get_name(modObj);
-        /* check if there is a partial command name */
-        if (cmdlen > 0 && strncmp((const char *)pathname, 
-                                  &line[word_start], cmdlen)) {
-            continue;
-        }
-
-        if(!obj_get_config_flag(modObj)) {
-            const xmlChar* rpc_name;
-            rpc_name = obj_get_name(rpc);
-            if(0==strcmp((const char*)rpc_name, "create")) continue;
-            if(0==strcmp((const char*)rpc_name, "replace")) continue;
-            if(0==strcmp((const char*)rpc_name, "delete")) continue;
-        }
-
-#ifdef DEBUG_TRACE
-        log_debug2("\nFilling from module %s, object %s", 
-                   mod->name, pathname);
-#endif
-
-        int retval = cpl_add_completion(cpl, line, word_start, word_end,
-                                        (const char *)&pathname[cmdlen],
-                                        "", "");
+        retval = xpath_path_completion_common(rpc, modObj, cpl, line, word_start, word_end, cmdlen);
         if (retval != 0) {
             return ERR_NCX_OPERATION_FAILED;
         }
@@ -816,17 +871,20 @@ static status_t
               // The second '/' is found
               // TODO: find the top level obj and fill its child completion
 //            log_write("more than 1\n");
-              obj_template_t * topObj = find_xpath_top_obj(comstate, line,
-                                                           word_start,
-                                                           word_iter);
+             obj_template_t * top_obj = find_xpath_top_obj(comstate, line,
+                                                          word_start,
+                                                          word_iter);
 
-              cmdlen = word_end - word_iter;
+             if(top_obj==NULL) {
+                 return NO_ERR;
+             }
+             cmdlen = word_end - word_iter;
 
-              // put the children path with topObj into the recursive 
-              // lookup function
-              return fill_xpath_children_completion (rpc, topObj, cpl, line,
-                                                     word_iter, word_end, 
-                                                     cmdlen);
+             // put the children path with topObj into the recursive
+             // lookup function
+             return fill_xpath_children_completion (rpc, top_obj, cpl, line,
+                                                    word_iter, word_end,
+                                                    cmdlen);
         }
         word_iter ++;
     }
@@ -1287,7 +1345,7 @@ static status_t
     *expectparm=TRUE;
 
     yangcli_wordexp(line, &p, 0);
-
+    //yangcli_wordexp_dump(&p);
     for (i = 0; i < p.we_wordc; i++) {
         if(p.we_word_line_offset[i]+strlen(p.we_wordv[i])==word_end) {
             /*cursor at the end of a parameter[=value] - completion possible*/
@@ -1295,7 +1353,11 @@ static status_t
         } else if((p.we_word_line_offset[i]<=word_end) && (p.we_word_line_offset[i]+strlen(p.we_wordv[i])>word_end)) {
             /*cursor in the middle of parameter[=value] - completion not possible*/
             *emptyexit=TRUE;
-            return;
+            return NO_ERR;
+        } else if(0==strcmp("--",p.we_wordv[i])) {
+            /* no completion currently supported for secondary arguments e.g. create /interfaces/interface -- loopback=...*/
+            *emptyexit=TRUE;
+            return NO_ERR;
         }
     }
     if(i==p.we_wordc) {
