@@ -733,131 +733,6 @@ status_t
 
 }  /* check_filespec */
 
-
-/********************************************************************
- * FUNCTION get_instanceid_parm
- * 
- * Validate an instance identifier parameter
- * Return the target object
- * Return a value struct from root containing
- * all the predicate assignments in the stance identifier
- *
- * INPUTS:
- *    target == XPath expression for the instance-identifier
- *    schemainst == TRUE if ncx:schema-instance string
- *                  FALSE if instance-identifier
- *    configonly == TRUE if there should be an error given
- *                  if the target does not point to a config node
- *                  FALSE if the target can be config false
- *    targobj == address of return target object for this expr
- *    targval == address of return pointer to target value
- *               node within the value subtree returned
- *    retres == address of return status
- *
- * OUTPUTS:
- *    *targobj == the object template for the target
- *    *targval == the target node within the returned subtree
- *                from root
- *    *retres == return status for the operation
- *
- * RETURNS:
- *   If NO_ERR:
- *     malloced value node representing the instance-identifier
- *     from root to the targobj
- *  else:
- *    NULL, check *retres
- *********************************************************************/
-val_value_t *
-    get_instanceid_parm (const xmlChar *target,
-                         boolean schemainst,
-                         boolean configonly,
-                         obj_template_t **targobj,
-                         val_value_t **targval,
-                         status_t *retres)
-{
-    xpath_pcb_t           *xpathpcb;
-    val_value_t           *retval;
-    status_t               res;
-
-#ifdef DEBUG
-    if (!target || !targobj || !targval || !retres) {
-        SET_ERROR(ERR_INTERNAL_PTR);
-        return NULL;
-    }
-#endif
-
-    *targobj = NULL;
-    *targval = NULL;
-    *retres = NO_ERR;
-
-    /* get a parser block for the instance-id */
-    xpathpcb = xpath_new_pcb(target, NULL);
-    if (!xpathpcb) {
-        log_error("\nError: malloc failed");
-        *retres = ERR_INTERNAL_MEM;
-        return NULL;
-    }
-
-    /* initial parse into a token chain
-     * this is only for parsing leafref paths! 
-     */
-    res = xpath_yang_parse_path(NULL, 
-                                NULL, 
-                                (schemainst) ?
-                                XP_SRC_SCHEMA_INSTANCEID :
-                                XP_SRC_INSTANCEID,
-                                xpathpcb);
-    if (res != NO_ERR) {
-        log_error("\nError: parse XPath target '%s' failed",
-                  xpathpcb->exprstr);
-        xpath_free_pcb(xpathpcb);
-        *retres = res;
-        return NULL;
-    }
-
-    /* validate against the object tree */
-    res = xpath_yang_validate_path(NULL, 
-                                   ncx_get_gen_root(),
-                                   xpathpcb,
-                                   schemainst,
-                                   targobj);
-    if (res != NO_ERR) {
-        log_error("\nError: validate XPath target '%s' failed",
-                  xpathpcb->exprstr);
-        xpath_free_pcb(xpathpcb);
-        *retres = res;
-        return NULL;
-    }
-
-    /* check if the target is a config node or not
-     * TBD: check the baddata parm and possibly allow
-     * the target of a write to be a config=false for
-     * server testing purposes
-     */
-    if (configonly && !obj_get_config_flag(*targobj)) {
-        log_error("\nError: XPath target '%s' is not a config=true node",
-                  xpathpcb->exprstr);
-        xpath_free_pcb(xpathpcb);
-        *retres = ERR_NCX_ACCESS_READ_ONLY;
-        return NULL;
-    }
-    
-    /* have a valid target object, so follow the
-     * parser chain and build a value subtree
-     * from the XPath expression
-     */
-    retval = xpath_yang_make_instanceid_val(xpathpcb, 
-                                            &res,
-                                            targval);
-
-    xpath_free_pcb(xpathpcb);
-    *retres = res;
-
-    return retval;
-
-} /* get_instanceid_parm */
-
-
 /********************************************************************
 * FUNCTION get_file_result_format
 * 
